#
# spec file for package shotcut
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Find qt version used to build
%define qt5version %(pkg-config --modversion Qt5Core)

%bcond_with    x264

# Internal QML imports
%global __requires_exclude qmlimport\\((Shotcut\\.Controls|org\\.shotcut\\.qml).*

Name:           shotcut
Version:        21.03.21
Release:        bp153.1.1
# This package creates a build time version from the current date and uses it to check
# for updates. See patch1 and prep/build section. For reproducible builds.
%define _vstring %(echo %{version} |tr -d ".")
Summary:        Video and audio editor and creator
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            http://www.shotcut.org/
Source:         https://github.com/mltframework/shotcut/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  mc
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.9.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickControls2)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(mlt++) >= 6.7.0
BuildRequires:  pkgconfig(mlt-framework) >= 6.7.0
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vpx)
# frei0r-plugins prior to 1.4-7.1 are built against qt4 and cause a segfault on startup.
Requires:       frei0r-plugins >= 1.4-7.1
Requires:       ladspa
Requires:       libmlt6-modules > 6.6.0
Requires:       melt > 6.6.0
Recommends:     lame
Requires:       ffmpeg >= 2.7
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libvpx.so) --qf '%%{NAME} >= %%{VERSION}')
%if %{with x264}
BuildRequires:  pkgconfig(x264)
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libx264.so) --qf '%%{NAME} >= %%{VERSION}')
%endif
# needed on runtime for the timeline to work see https://forums.opensuse.org/showthread.php/520592-shotcut-video-editor-timeline-blank/page3
Requires:       libQt5Sql5-sqlite
Requires:       libqt5-qtgraphicaleffects >= %{qt5version}
Requires:       libqt5-qtquickcontrols2 >= %{qt5version}

%description
Shotcut is an audio/video editor. It supports most audio, video and
image formats, as well as image sequences with a wide range of
filters and effects. It's compatible with JACK Audio and Melted
Server, and offers an experimental GPU Processing feature.
Shotcut can test MLT XML files, too.

%lang_package

%prep
%setup -q
echo "Qt5Core = %{qt5version}"
%autopatch -p1

# Search for executable files
find . \
\( -name \*.html -o -name \*.js \) -type f -executable -exec chmod a-x {} + || :

%build
##if LIBMLT_VERSION_INT >= MLT_VERSION_CPP_UPDATED 397568
##define LIBMLT_VERSION_INT 397312     ((LIBMLT_VERSION_MAJOR<<16)+(LIBMLT_VERSION_MINOR<<8)+LIBMLT_VERSION_REVISION)
%qmake5 \
	QMAKE_STRIP="" \
        PREFIX="%{_prefix}" -Wall -recursive \
        SHOTCUT_VERSION=%{version} \
        DEFINES+=SHOTCUT_NOUPGRADE

make %{_smp_mflags} VERBOSE=1
# CC=gcc-8 CPP=cpp-8 CXX=g++-8
%install
%qmake5_install

install -D icons/%{name}-logo-64.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png

# Install language files
langlist="$PWD/%{name}.lang"
langdir="%{_datadir}/%{name}/translations"
basedir=$(basename "$langdir")
pushd $basedir
	for ts in *.ts; do
		[ -e "$ts" ] || continue
		lupdate-qt5 "$ts" && lrelease-qt5 "$ts"
	done
	for qm in *.qm; do
		[ -e "$qm" ] || continue
		if ! grep -wqs "%dir\ $langdir" "$langlist"; then
			echo "%dir $langdir" >>"$langlist"
		fi
		install -Dm0644 "$qm" "%{buildroot}/$langdir/$qm"
		lang="${qm%.qm}"
		echo "%lang($lang) $langdir/$qm" >>"$langlist"
	done
popd
%suse_update_desktop_file -i org.%{name}.Shotcut
chmod 0755 %{buildroot}/%{_datadir}/%{name}/qml/export-edl/rebuild.sh
%fdupes -s %{buildroot}/%{_datadir}

%post
%mime_database_post
%desktop_database_post

%postun
%mime_database_postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_datadir}/icons/hicolor/64x64/apps/org.shotcut.Shotcut.png
%{_datadir}/icons/hicolor/128x128/apps/org.shotcut.Shotcut.png
%{_datadir}/metainfo/
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/mime/
%{_datadir}/applications/org.%{name}.Shotcut.desktop
%exclude %{_datadir}/%{name}/translations

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sun Apr 11 2021 Dave Plater <davejplater@gmail.com>
- Removed the dependency on obsolete qmelt
* Wed Apr  7 2021 Michael Vetter <mvetter@suse.com>
- Update to 21.03.21:
  * Fixed <tractor> and blank considered missing and blocking export (broke in v21.01).
  * Added an Ignore button to the missing files error dialog in Export.
  * Fixed black frames appearing in Slideshow Generator (broke in v20.02).
  * Fixed being able to use mouse wheel over Timeline and Keyframes zoom sliders (broke in v20.01).
  * Improved sound quality with small changes in Speed with Pitch Compensation or Pitch audio filter (broke in v20.11).
  * Fixed the Timeline clip audio waveform incorrect after adding transition by dragging the clip left.
  * Fixed repairing a project file opened using a network path on Windows.
  * Fixed writing a raw FLAC file does not set its duration.
  * Fixed an elided file name in clip Properties can become the clip name.
* Mon Mar  1 2021 Michael Vetter <mvetter@suse.com>
- Updaet to 21.02.27:
  New:
  * Added a file naming dialog for Export > From > Each Playlist Item > Export File.
  * Added the ability to repair a near future version project file.
    (Version 21.04 is expected to change the project file in a manner incompatible with
    previous versions.)
  * Added an error dialog when trying to open a far future version project file.
  Changes:
  * Upgraded JACK audio library on Windows to version 1.9.17.
  Fixes:
  * Fixed a possible crash using a PNG with alpha channel (transparency) especially with
    a Size, Position & Rotate filter (broke in version 20.06).
  * Fixed seeking video in some files particularly AVCHD (broke in v21.01).
  * Fixed changing Properties > Video > Color Range does not work (broke in v21.01).
  * Fixed selecting text with the mouse in various filter numeric fields (broke in
    v21.01).
  * Fixed difficult to enter some numbers in various filter numeric fields (broke in
    v21.01).
  * Fixed unable to make tracks as short as before (broke in v21.01).
  * Fixed time bar in Timeline & Keyframes hidden on vertical scroll and not clickable
    (broke in v21.01).
  * Fixed scroll bars in Timeline & Keyframes may clash with clips or keyframes making
    them difficult to use (regression in v21.01).
  * Fixed keyframes disappear when changing selected clips on various filters (broke in
    v21.01)
  * Fixed appending to the timeline may change the current track.
  * Fixed Properties > Extract sub-clip on a file with cover art.
  * Fixed File > Export Frame on a clip with a Text: Rich filter.
  * Fixed toggle Properties > Image sequence may deadlock on high frame rate video mode
    or break playback.
  * Fixed Timeline > Merge with next clip may move other clips on the track.
  * Fixed undo a trim in point on Timeline may shift other clips on the track.
  * Fixed undo after trim in point to create a 1 frame transition may delete the clip.
  * Fixed right-click in Playlist icons view mode breaks multiple selection on Windows.
  * Fixed Properties > Convert after Timeline > Detach Audio makes video black.
  * Fixed some keyboard shortcuts may be broken when not using Settings > Language >
    English (United States).
  * Fixed possible crash on Windows due to not loading the packaged DLL over one in a
    system folder or in %%PATH%%.
  * Fixed a crash when selecting a missing video clip.
  * Fixed unicode in Text: Rich > Save As followed by Open.
* Tue Feb  2 2021 Michael Vetter <mvetter@suse.com>
- Update to 21.01.29:
  * Fixed image skewed with odd width when using certain combinations of filters and transitions (broken in v20.11).
  * Fixed being unable to pick transparent black in filters with color pickers (broken in v20.11).
  * Fixed some tooltips in Timeline, Filters, & Keyframes not showing on multi-monitor systems (broken in v20.10).
  * Fixed Zoom in Scale, Position & Rotate does not always default and undo at 100%% (broken in v20.10).
  * Fixed crash with files having more than 32 multiplexed streams.
  * Fixed quality-based VBR encoding with the VP8 Export > WebM preset.
  * Fixed leading zeros for seconds in Timer video filter with MM:SS.SSS or SS.SSS formats.
  * Fixed support for explicit fractional high DPI (e.g. --QT_DISPLAY_SCALE 1.5).
  * Fixed bad text formatting when File > Open a plain text file in Text: Rich filter.
  * Fixed drag-n-drop from Playlist when a project (MLT XML clip) is in Source player.
  * Fixed using the numeric keypad for some shortcuts.
  * Fixed selecting the same filter Preset again.
  * Fixed Export File does not check for missing files.
  * Upgraded Qt to version 5.15.2 for Linux & Windows and 5.12.10 for macOS.
  * Improved the playback speeds of fast forward and rewind.
  * Changed Playlist to not automatically start playback when add to playlist of empty project.
  * Finished converting Timeline, Filters, & Keyframes to Qt Quick Controls 2 API.
  * Changed keyframe interpolation Discrete to Hold.
  * Improved multi-threaded performance of video track blending and video filters:
    + Alpha Channel: View
    + Chroma Key: Advanced
    + Chroma Key: Simple
    + Elastic Scale
    + Key Spill: Advanced
    + Key Spill: Simple
    + Levels
    + Mask: Apply
    + Noise: Keyframes
    + Posterize
    + Saturation
    + Unpremultiply
    + White Balance
  * Added support for AV1 decoding and encoding.
  * Added Color space and Color transfer to Properties > Video.
  * Added an Advanced mode to the Convert to Edit-friendly dialog with:
  * Added Deinterlace option (bwdif) that outputs one frame for each field.
  * Added Override frame rate and Frame rate conversion with Blend and Motion Compensation options.
  * Added Convert to BT.709 colorspace that provides HDR-to-SDR tonemapping.
  * Added detection of a HDR transfer function (ITU-R BT.2020 or SMPTE ST2084) to automatically show Convert dialog.
  * Added Use Higher Performance Waveforms to Timeline and Keyframes menus (default on).
  * Added a red outline around the thumnbail of the currently opened Playlist item.
  * Added video filter Reduce Noise: Quantization.
* Fri Jan 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 20.11.28:
  * Improved behavior when press enter/return in the current position timecode field.
  * Made it is easier to choose opaque black in the color chooser dialogs.
  * Changed numeric fields in Size, Position & Rotate and Text
  * Rich default size and postion to have a 10%% margin inside the frame.
  * Added a warning dialog when the computer is getting low on available memory.
  * Added Properties > menu > Set Equirectangular….
  * Added a Start Offset time parameter and Apply transform option to the 360:
  Stabilize video filter.
  * Added a Show Grid option to the 360: Transform video filter as a visual aid.
  * Added a dialog to confirm trying to add or paste filters to Timeline > Output.
  * Added Move Up, Move Down, and Deselect buttons to Filters.
  * Added command line option --QT_SCALE_FACTOR_ROUNDING_POLICY
  * Lots of bugfixes see https://shotcut.org/blog/new-release-201125/
* Mon Nov  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 20.10.31:
  New:
  * Added Invert (reverse polarity) audio filter.
  * Added showing the job progress in Windows taskbar icon.
  * Added Size, Position & Rotate > Zoom now works in any Size mode!
  * Added Scroll to Playhead on Zoom to Keyframes menu.
  * Added converting Text: HTML filters to Text: Rich. This does not
    retain full fidelity, but hopefully it retains the text.
  * Added using the H.264 hardware encoder if HEVC not available
    when Proxy > Use Hardware Encoder is on.
  * Added Scroll to Playhead on Zoom option to Timeline menu.
  * Added ability to change position in Size, Position & Rotate
    by dragging anywhere inside the rectangle while also holding Shift.
  * Added rectangle VUI help tips for various video filters.
  * Added keyboard shortcut for Center the Playhead: Ctrl+Shift+P.
  * Added keyboard shortcut for Scroll to Playhead on Zoom: Ctrl+Alt+P.
  * Added keyboard shortcut for rich text editor Paste Text Only: Ctr+Shift+V
  * Added common preset resolutions and aspect ratios to the Add Custom
    Video Mode dialog.
  Changes:
  * Improved image quality when using Size, Position & Rotate.
  * Improved Text: Rich filter export on Windows and Linux when display
    scale is fractional (e.g. 150%%).
  * Improved the performance of the Fade In Video, Fade Out Video, and
    Brightness filters on multicore systems.
  * Changed Export > Codec > Dual pass to not write a video file for the first pass.
  * Removed “Shotcut” as default text in Text: Rich filter.
  * Reduced memory usage in Export with many clips.
  Fixes:
  * Fixed a compatibility issue for some systems by downgrading FFmpeg
    to version 4.2 (regression in v20.09).
  * Improved the Timeline scrolling speed and smoothness (regression in v20.09).
  * Fixed time rulers hiding on vertical scroll in Timeline and
    Keyframes (regression in v20.09).
  * Fixed Crop: Rectangle > Corner radius not exactly the same as in
    version 20.07 (regression in v20.09).
  * Fixed Blur: Pad incorrect after splitting clip.
  * Fixed moving the cursor in filter fields may move playhead.
  * Fixed Filters allowed pasting filters when nothing selected.
  * Fixed saving projects to Dropbox on Windows leaves temporary files.
  * Fixed saving the current stock layout when switching to a custom layout.
  * Fixed progress dialog appears over the convert variable frame rate dialog
    when dragging to Timeline.
  * Fixed dropping file with comma in its name to Timeline.
  * Fixed delete keyframe button in Keyframes may remove keyframe for
    another parameter.
  * Fixed convert dialog for variable frame rate never appears if
    dragged directly to non-empty playlist or timeline.
  * Fixed a crash dragging multiple clips to Timeline if some are
    variable frame rate.
  * Fixed the Blur: Pad filter appearing correctly if used that
    option in slideshow generator.
  * Fixed zooming in near end of timeline scrolls timeline backward.
  * Fixed deleting all text in Text: Rich filter changes font to very small black.
  * Fixed editor toolbar in Text: Rich filter usually overlays the text by default.
- Remove shotcut-with-mlt-6.16.0.patch: upstreamed
* Tue Oct  6 2020 Michael Vetter <mvetter@suse.com>
- Update to 20.09.27:
  Regressions In Version 20.09.13:
  * Fixed setting color alpha (opacity) to 0 in Open Other >
    Color and Open Other > Text.
  * Fixed a possible crash when using Center bias in the Crop: Source filter.
  Text: Rich Video Filter:
  * Fixed incorrect font size in export on Windows when the system Settings > Display >
    Scale and layout is higher than 100%% (High DPI).
  * Fixed problems when Export > Video > Parallel processing is on.
  * Added collpase & expand buttons to the editor’s toolbar.
  * Added an Overflow parameter to allow text longer (taller) than the rectangle.
  * Added Paste Text Only to the editor’s menu to faciliate pasting from a word processor
    or web browser without applying the source formatting.
  * Fixed the Scroll Up and Scroll Down presets when the background is not transparent.
  * Added a Lower Third preset to Text: Rich.
  Other:
  * Fixed the actual workspace layout may not match the currently selected layout when
  restarting after a crash.
  * Fixed Filters and Keyframes broken on Source clip after changing Settings > Video
  Mode.
* Mon Sep 21 2020 Michael Vetter <mvetter@suse.com>
- Update to 20.09.13:
  Changes:
  * Improved the performance of the Timeline especially with projects over one hour long.
  * Changed Size and Position to Size, Position & Rotate and made Rotate and Scale hidden (only appears in old projects).
  * Replaced Choppy, Crop: Circle, and Crop: Rectangle filters with new versions that do not use HTML through WebVfx, which was deprecated in version 20.06.28.
  * Changed the Rutt-Etra-Izer, Swirl, and Text: 3D filters to be hidden since they are deprecated (still loads in old projects).
  * Changed the video track hidden icon on the System theme to be more clear and obvious.
  * Show an error dialog on startup if the frei0r plugins are not installed (only affects Linux distribution packages).
  * Changed the keyboard shortcut 0 to zoom timeline to fit.
  * Changed the keyboard shortcut Alt+0 to zoom playlist to fit.
  * Changed the Timeline and Keyframes time ruler interval to 1 second when zoomed in.
  * Upgraded FFmpeg to version 4.3.1.
  Fixes:
  * Fixed using a secure connection to get the upgrade URL.
  * Fixed a rounding error for Color Grading video filter.
  * Fixed a crash and incorrect preview scaling with more than one Rotate and Scale or Size and Position filter.
  * Fixed colors when using an alpha/VP8 or alpha/VP9 export preset.
  * Fixed video compositing with nothing on video track V1 or V1 hidden.
  * Fixed export may fail when using extended (non-Latin-1) characters in path.
  * Fixed EDL export.
  * Fixed Export, Convert, or Reverse may fail if a temporary file it creates becomes locked on Windows.
  * Fixed Properties > Color button not opening the color dialog with the current color.
  * Fixed the Crop: Source video filter when using Settings > Proxy.
  * Fixed a crash when dragging a MLT XML project file to a non-empty Timeline.
  * Fixed the font dialog may too big or the preview inside the font dialog too big for the Text: Simple filter.
  * Fixed filters not being applied to the portion of a clip inside a transition after undo of Cut, Lift, Remove, Ripple Delete, or move.
  * Fixed a crash changing speed of a clip with non-standard non-integer or variable frame rate.
  * Fixed some dialogs not opening or staying in the foreground.
  * Fixed some crashes in timeline overwrite mode.
  * Fixed clicking the filters icon next to Output not opening the filters panel.
  * For details see https://www.shotcut.org/blog/new-release-200913/
* Tue Aug 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 20.07.11:
  * Fixed noisy sound playback on some Windows systems.
  * Fixed UI layout glitches and default/minimum size of timeline
    too short.
  * Fixed Quick Sync Video hardware encoder (h264_qsv or hevc_qsv
    withQuality-based VBR) not working on Windows on older Intel chips.
  * Fixed Properties > Speed not working correctly on trimmed
    clip in Source player.
  * Fixed Stabilize and Normalize: Two Pass filters not working
    on trimmed clip in Source player.
- Remove shotcut-QPainterPath.patch: upstreamed
* Fri Jun  5 2020 Dave Plater <davejplater@gmail.com>
- Fix Factory build with shotcut-QPainterPath.patch submitted
  upstream https://github.com/mltframework/shotcut/issues/874
* Tue Apr 28 2020 Pavol Cupka <palica@liguros.net>
- update to release version 20.04.12
- upstream changes please see:
  https://github.com/mltframework/shotcut/releases/tag/v20.04.12
* Tue Feb 18 2020 Pavol Cupka <palica@liguros.net>
- Update to release version 20.02.17
- Upstream changes:
  - Fixes:
  - Fixed dropping multiple files to Playlist in a new project (broken in v19.12.31).
  - Fixed some broken keyboard shortcuts in the Turkish translation.
  - Fixed Properties > Speed not working after a project file repair.
  - Fixed clip selection after Insert Track or Remove Track.
  - Fixed Playlist > Add Selected to Timeline creates corrupt clips (broken in v19.12.31).
  - Fixed Settings > Display Method > Software (Mesa) on Windows (broken in v19.12.31).
  - Fixed creating a Project folder with leading or trailing spaces.
  - Fixed saving the length property in MLT XML as a time value independent of frame rate.
  - Fixed starting Text: Simple video filter with "@" shows "0".
  - Fixed seeking previous & next on the first track in Keyframes where you trim a filter or use simple keyframes.
  - Fixed an unexpected transition is created when moving a clip rightward adjacent to the next clip in Timeline (regression in v19.12.16).
  - Fixed drag-n-drop from Source player to Timeline left player in an inconsistent state (broken in v19.09.14).
  - Fixed an inconsistent colorspace conversion when accessing a cached image.
  - Fixed Playlist > Copy followed by a change in Properties incorrectly changes the playlist item.
  - Fixed clicking on the rectangle control may change its size.
  - Fixed using the LUT (3D) filter with file with extended characters in its file path on Windows.
  - Fixed a crash when using a transition on every track at the same time.
  - Changes:
  - Improved the reliability of Timeline > Select None.
  - Changed Timeline > Master > Properties > Frame rate to show 6 decimal digits.
  - Reduced the latency of scrubbing (regression in v19.12.31).
  - Changed the video-overlay rectangle control used in some filters to allow changing the position by dragging from anywhere inside the rectangle.
  - To enable, one must first double-click the center circle to put it into a positioning-locked mode. Otherwise, you would be prevented from dragging the clip out of the Source player.
  - Changed the Filters panel on macOS to prevent floating to avoid a frequently reported problem of the Filters window appearing blank/black.
  - Changed Timeline > clip context menu > Detach Audio to not seek afterwards.
  - Improved mouse wheel and trackpad behavior in Timeline.
  - Now, you do not need to ensure the mouse pointer is over a clip, speed is reduced, and zoom keeps focal point in view. The new zoom behavior does not apply when using the option Center the Playhead in the timeline menu.
  - Upgraded MLT to version 6.20.0 and WebVfx to version 1.2.0.
  - New:
  - Added Settings > Preview Scaling!
    This reduces the resolution for rendering effects for preview within the app, but there may be added a fair cost to the CPU for down-scaling sources to the preview resolution. Thus, this will be more beneficial when low resolution proxies are created, which is planned for version 20.04 in April.
    Please understand that preview scaling will not always provide perfect fidelity. Some differences are unavoidable especially where blur, softness, and noise are concerned.
    Some filters may not support preview scaling and will process at full project resolution:
    Choppy
    Rutt-Etra-Izer
    Stabilize
    Text: HTML > Blank with Web Animations
    Text: HTML > Simple Scroll
    Text: HTML > Two Column Scroll
  - Added Export > Advanced > Video >Use preview scaling.
    This is intended to provide a faster export for draft review. You should leave the export resolution set to the project resolution unless your preset or video codec dictates a resolution.
  - Added Views > Scopes > Video Vector.
    Note that the graticule on this is non-traditional, inspired by Alexis Van Hurkman.
  - Added Filters > Audio > Pitch.
    This is handy when changing the speed of a clip anywhere from 4.0x - 0.25x.
  - Added the ability to rename clips in Properties by clicking into the header where the name is displayed.
  - Added support for using a video clip in Transition Properties > Video.
    This is handy to use with @jonray's matte transitions.
  - Added a few more export presets:
    audio/ALAC
    audio/FLAC
    intermediate/DNxHR HQ
    intermediate/ProRes HQ
    intermediate/ProRes was changed to ProRes 422
  - Added Arabic translation.
- Remove patch shotcut-noupdatecheck.patch no longer needed,
  the package can be now configured to not check for updates
* Sat Feb 15 2020 Pavol Cupka <palica@liguros.net>
- Update to release version 19.12.31
* Sun Sep 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to release version 19.09.14
- Upstream changes:
  * Added the option Play After Open (default on) to the playlist menu
  to control above behavior.
  * Added multi-select to Playlist as well
  as Select All (Ctrl+Shift+A) and Select None (Ctrl+Shift+D) to its
  menu.
  * Added multi-select to Timeline, which is currently limited to
  the remove/delete and lift operations.
  * Added Select All (Ctrl+A)
  and Select None (Ctrl+D) to the Timeline menu.
  * Added keyboard shortcuts for some existing Timeline menu actions:
  Insert Track (Ctrl+Alt+I)
  Remove Track (Ctrl+Alt+U)
  Copy Timeline to Source (Ctrl+Alt+C)
  * Added new video filters:
  Dither
  Halftone
  Posterize
  Threshold
  Elastic Scale (non-linear horizontal scaling)
  Blend Mode (overrides the track Properties > Blend mode for that clip).
  * Fixed a crash in some audio filters when using 1 or 6
  channels.
  * Fixed showing language English (Great Britain) when
  English (United States) is chosen.
  * Fixed a crash bug in v19.06 when
  changing image sequence Repeat in Properties.
  * Fixed a bug in v19.08 where dropping a video into Playlist on a
  new project does not update the Automatic Video Mode.
  * Fixed a bug in v19.08 in the
  on-screen rectangle control (as used in Text: Simple and Size and
  Position filters among a few others).
  * Fixed changing speed of a
  clip with a colon in the file name.
  * Fixed reading MLT XML with a
  colon in the file name of a relative path.
  * Fixed the playlist menu button disabled after removing all clips.
  * Fixed reloading Fade In
  Video or Fade Out Video using opacity may alter the colors.
  * Fixed Convert to Edit-friendly failing on GoPro videos.
  * Fixed filters
  during a transition are truncated after a Split on the timeline.
  * Fixed a bug in v19.08 where Keyframes becomes broken after trimming
  on the timeline.
  * Reduced the size of the installation by 255 MiB
  (by removing share/mlt/lumas/*.pgm and computing them on-demand).
  * Upgraded FFmpeg to v4.2.
  * Increased export process priority on
  Windows from Low (idle) to Below Normal.
  * Changed default HEVC
  quality to 45%% so the x265 crf matches its default of 28.
  * Added the clip's name to the end of a clip in Timeline if its
  block is wide enough.
  * No longer seek after dropping a clip from the player to the
  Timeline.
* Thu Aug 22 2019 Aaron Stern <ukbeast89@protonmail.com>
- Update to release version 19.08.16
- Upstream changes:
  * Changed Playlist > Open As Clip to simply Open. This action now opens the playlist item directly in the Source player, and all changes made in Source (trim in/out), Properties, Filters, and Keyframes apply to the playlist item immediately without an explicit update.
  * Added Playlist > Copy that opens a copy of the playlist item in Source just like the old behavior. This is useful if you want to trim out another shot from the same source clip or create a different sub-clip with different filtering.
  * Changed double-click on a playlist item to Open the clip instead of Copy it.
  * Added keyboard shortcut Shift+C to Copy a playlist item.
  * Now, when you drag a clip from Playlist to Timeline the timeline shows an appropriately-size box on a track.
  * Fixed a performance regression (since v19.06) in the following filters: Chroma Hold, Flip, LUT 3D, Mirror, Noise: Fast, Reduce Noise: Smart Blur.
  * Fixed reloading the filter UI for Rutt-Etra-Izer, Text: 3D, and Text: HTML resets the filter trimming in Keyframes.
  * Added support for keyframes to the Lens Correction and Mosaic video filters.
  * Fixed Swirl when maximum = 0%%.
  * Changed the minimum values for Mosaic to 0%%.
  * Removed the scrolling animation from the Blank Web Animations HTML template.
  * Fixed pasting filters changes the trim and keyframes of the existing filters.
  * Fixed Crop: Circle and Crop: Rectangle not clearing the canvas resulting in trails in some situations.
  * Fixed color incorrect when using the LUT 3D filter with some other filters following it.
  * Fixed reliability of the Stabilize video filter to write its results (.stab) file.
  * Fixed showing vidstab.trf as a missing file.
  * Fixed updating Stabilize and Normalize: Two Pass results to clips copied between Source, Playlist, and Timeline.
  * Added the ability for the Stabilize and Normalize: Two Pass filters' analysis jobs to update pending export jobs.
  * Added the option to run pending Stabilize and Normalize: Two Pass filters' analysis jobs on export. This only works for Stabilize if you are using the project folder feature. Or, if not using the project folder feature, you must click Analyze to assign a results file name, but you can stop the analysis job.
  * The combination of the above fixes and changes means you can now easily batch convert files while applying image stabilization and audio normalization!
  * Added support for interlace output to Properties > Reverse and Convert to Edit-friendly including overrides for Scan mode and field order.
  * Improved detection of interlaced video in some files such as Ut Video in Matroska.
  * Added Comments to image properties along with a menu button with: Copy Full File Path, Show in Folder, and Set Creation Time...
  * Add resolution and refresh rates to the screens in Settings > External Monitor to make them easier to differentiate.
  * Fixed switching between different external screens on the same GPU.
  * Fixed external screen not showing on correct screen in some arrangements.
  * Changed the default video quality to 55%% for the Default and YouTube presets. This aligns with the x264 default crf of 23 and produces a smaller file that most people desire for upload without significant quality loss.
  * Added text after Export > Advanced > Codec > Quality to show the generated codec-specific quality level (e.g. crf for x264).
  * Fixed Stream broken by check for writable file.
  * Fixed double-click in Recent Projects loading twice.
  * Fixed disabling meters in the Audio Loudness scope not shrinking space.
  * Added version metadata to the AppImage for Linux.
  * Added md5sums.txt and sha256sums.txt to the GitHub releases page.
  * Added saving Timeline track height to configuration, not only a project file.
  * Fixed trimming an unselected clip in Timeline does not correctly adjust its filters.
  * Changed Settings > Interpolation > Nearest Neighbor to no longer relax seek accuracy. Instead, seek accuracy is now relaxed only during trick playback (reverse, rewind, fast forward).
  * Added a Korean translation.
* Thu Aug  8 2019 Dave Plater <davejplater@gmail.com>
- Update to release version 19.08.05
- Added shotcut-with-mlt-6.16.0.patch to fix build with mlt < 6.17.0
- Upstream changes:
  * Use x264 default crf 23 = 55%%
  * Fix showing vidstab.trf as missing file.
  * Fix conflicting FindFilterParser classes.
  * Enqueue pending analysis jobs on export.
  * Convert Lens Correction to show percentage.
  * Cleanup previous commit to qmlfilter.cpp
  * Change shortcut Shift+C to be Playlist Copy.
  * Change Playlist Open and add Copy.
  * Add trim support to an opened playlist item.
  * Add text for conversion of quality %% in Export.
  * Add support for interlace to convert and reverse.
  * Add keyframes to Mosaic filter.
  * Add description to external screens (#757).
* Mon Jul  8 2019 Dave Plater <davejplater@gmail.com>
- Update to release version 19.07.07
- Upstream changes:
  * Use DNxHR instead of ProRes in Convert/Reverse.
  * Fix filters added after transitions.
  * Fix incorrect audio waveform after undo timeline insert.
  * Fix timecode of job failure if fps != 25 and not changed.
  * Use the producer width/height as limits for Crop: Source.
  * Fix vbr=constrained for libopus avergage bitrate.
  * Fix #753 multiple stabilize jobs write to same file.
  * Do not convert decimal in text of Text:Simple preset.
  * Fix #751 1080p50 missing from video modes.
  * Fix loading export preset with frame_rate_num/_den.
  * Fix #750 keyframes removed when trimming.
  * Fix seeking filter end not seeking timeline.
  * Fix save XML backup fails if removing temp file fails.
  * Show a message when project is loading.
  * Fix crash changing speed to very low by increasing minimum.
* Thu Jul  4 2019 Dave Plater <davejplater@gmail.com>
- Update to release version 19.06.15
- Upstream changes:
  * Changed the Timeline and Keyframes rulers interval to 5 seconds
  and show only HH:MM:SS and no frame units.
  * Renamed video filter Circular Frame to Crop: Circle.
  * Renamed video filter Crop to Crop: Source.
  * Renamed video filter Text to Text: Simple.
  * Renamed video filter 3D Text to Text: 3D.
  * Renamed video filter Overlay HTML to Text: HTML.
  * Renamed video filter Blur to Blur: Box.
  * Renamed Reduce Noise video filter to Reduce Noise: Smart Blur.
  * Changed Export > From to show Source instead of base file name.
  * Changed maximum duration of Color, Text, and Color Bars clips to
  4 hours.
  * Increased maximum value of the Timer filter’s Start Delay,
  Duration, and Offset parameters to 24 hours.
  * Improved Export Job progress and estimated time remaining.
  * Blur: Exponential (fast)
  * Blur: Low Pass (fast)
  * Blur: Gaussian (slow)
  * Show Text Under Icons (default on)
  * Show Small Icons (default off)
  * Added Jobs to the main toolbar. Jobs toolbar icon
  * Reordered panel buttons on main toolbar to match View menu.
  * Added Ripple All button to Timeline toolbar. Ripple all tracks
  icon
  * Added a vertical Flip video filter.
  * Added Reduce Noise: HQDN3D video filter.
  * Added Noise: Fast video filter.
  * Added Noise: Keyframes video filter.
  * Added Add Keyframe button in Keyframes (only on parameters that
  show a curve UI). Add keyframe icon
  * Added keyboard shortcuts Ctrl+0-9 to toggle the panels.
  * Added Alt 0/+/- shortcuts to adjust the zoom in Keyframes.
  * Added Swedish translation.
  * Fixed deleting the project file if there was a save error.
  * Fixed Crop: Source filter not working with Color clip.
  * Fixed using filters on Color Bars and other generator clips.
  * Fixed audio filters (Compressor, Expander, Limiter, Notch,
  Reverb) broken\ on comma for decimal.
  * Fixed alpha video opaque on gaps in Timeline.
  * Fixed Convert to Edit-friendly and Reverse if there is no audio
  track.
  * Fixed Measure Video Quality broken.
  * Fixed Alpha: Adjust > Invert checkbox on reload.
  * Fixed color eye-dropper (picker) error.
  * Fixed audio Pan filter channel resets on reload.
  * Fixed a crash using Mirror filter before Rotate and Scale or
  Size and Position.
  * Fixed poor Reverse audio quality for mp4 and mkv options.
  * Fixed the Simple Scroll HTML template may not scroll up or left
  completely.
* Thu May  9 2019 plater <davejplater@gmail.com>
- Set minimum qt version to 5.9.0
* Wed May  8 2019 plater <davejplater@gmail.com>
- Update to release 19.04.30.
  Upstream changes:
    Added:
  * (creation) Date column to Playlist Details view.
  * Set File Date… to the Playlist menu and item context menu.
  * Sort By Name and Sort By Date to the Playlist menu.
  * These are single-shot sorting commands. The playlist is still
  fixed-ordering. The new options do not automatically sort new
  playlist entries.
  * new video filters:
    Grid
    Audio Dance Visualization
    Audio Light Visualization
    RGB Shift
    Glitch
    Distort
  * Zoom 300%%, 400%%, 500%%, 750%%, and 1000%% to the zoom menu.
  * Display Method > OpenGL or Software (Mesa) on Linux.
  * Norwegian Nynorsk translation.
  Fixed:
  * reading some AVCHD files after a camcorder splits.
  * Video Waveform scope graticule not showing on non-dark theme.
  * incorrect compositing z-order after Insert Track.
  * current track changes after inserting or overwriting a clip in
  Timeline.
  * first clip does not start at beginning when drop to Timeline
  after File > New or File > Close.
  * Properties > Convert and Reverse on files with album art or
  embedded thumbnail.
  * a possible crash on File > New or File > Close.
  * filters on clips not extended into transition when adding a
  transition by trimming or resizing a transition.
  * Open Other > ALSA Audio on toolbar on Linux.
  * changing Properties > Speed or Color Range on a timeline clip
  may crash.
  * timeline correction when drag clip to another track and then
  back to original.
  * reloading the Mask: From File filter resets Threshold keyframes.
  * the Mask: Simple Shape filter does not work when Width or Height
  is 0%%
* Tue Mar  5 2019 mvetter@suse.com
- Update to version 19.02.28:
- Upstream changes:
  * Added Offset to the Timer video filter.
  * Added Vertical HD 30 fps and Vertical HD 60 fps video modes.
  * Added support for HTTPS.
  * Added --QT_SCALE_FACTOR and --QT_SCREEN_SCALE_FACTORS[4]
    command line options.
  * Added English (Great Britain) translatio
  * Fixed opening image sequence on Windows with extended/special
    characters in file path/name.
  * Fixed crash on some video clips, particularly those with
    Google Pixel 3 and likely others.
  * Fixed field order with interlaced export.
  * Fixed an image artifact when using keyframes with the Mask:
    Simple Shape filter.
  * Fixed image and alpha channel integrity with transitions on
    clips with a non-opaque alpha channel.
  * Fixed a crash when changing clip Properties > Audio > Track.
  * Fixed Properties > Video > Color Range inaccurate after
    changing it.
  * Fixed Shake One Second presets in regions that use comma for
    decimal point.
  * Fixed moving a Playlist item to the end.
  * Fixed more dialogs to be modal to prevent them from going
    behind the main window.
  * Fixed Overlay HTML webvfx templates when using a project folder.
  * Fixed volume slider appears before main window at launch on macOS.
  * Fixed more dialogs to use sheet style on macOS.
  * Fixed a few small memory leaks in MLT.
  * Changed Width and Height minimum to 0 for Blur filter.
  * Set the Save as type list on all file save dialogs.
  * Improved the quality of Export Frame > WebP.
  * Show “Not Seekable” instead of “Live” when opening a
    non-seeable clip (or device or stream).
  * Show a status message when trying to drag from Project player.
  * Prefer loading DLLs in Shotcut’s install folder over
    those in System32.
  * Default the out point of the Color, Count, and Text generator
    clips to the same as image duration (default 4 seconds).
* Mon Feb  4 2019 davejplater@gmail.com
- Update to version 19.01.27
- Upstream changes:
  * Fix reloading the Levels on locale with comma as radix.
  * Fix reload the Swirl filter UI.
* Fri Jan 25 2019 davejplater@gmail.com
- Update to version 19.01.24
- Upstream changes:
  * Fix Mirror filter before an offine filter.
  * Fix right click keyframe changes its position.
  * Fix distortion changing Scale param keyframe type.
  * Add HTML templates for Creative Commons Music.
  * Add margin: 0 to other HTML templates.
  * Remove HTML resources no longer used.
  * Add Swirl filter based on GL Transitions.
  * Fix Simple Scroll template does not scroll completely.
  * Fix #689 new project broken on KDE Linux.
  * Add Chroma Hold video filter.
  * Fix extended chars using Alt key on Windows.
  * Fix escape color picker leaves filter disabled.
  * Let Chroma Key Simple picker disable filter.
  * Fix disable QmlFilter checkbox state.
  * Fix dropping file with special characters.
* Sun Jan 20 2019 davejplater@gmail.com
- Update to version 19.01.19 and remove shotcut-QAction.patch which
  is no longer relevant.
- Upstream changes:
  * Fix Overlay HTML filter height.
  * Use generic sans-serif font face instead of Arial.
  * Add templates for Overlay HTML.
  * Fix using relative path to asset in HTML editor.
  * Add SVG to the HTML editor's open image dialog.
  * Add Slow Zoom, Hold presets.
  * Remove the old presets with "Pan" in them.
  * Change animation presets Pan -> Move.
  * Fix calling the correct parent onFinished().
  * Auto retry export job without parallel processing.
  * Add Center Playhead to the Keyframes menu.
  * Add Center Playhead option to Timeline menu.
  * Fix aspect ratio for Export Frame.
  * Fix trim to remove transition adds frames.
  * Fix ripple trim when clip has a transition.
  * Fix filter not adjusted when trim transition.
  * Change maximum for Speed to 50.
  * Default to first DirectShow devices.
  * Improve Color Grading filter UI.
  * Fix speed when the region and language radix differ.
  * Fix changing speed can move clip.
  * Refactor m_updateCommand to QScopedPointer.
  * Fix no hardware encoders found with space in path.
  * Fix Video Mode in New Project.
  * Prioritize display over other frameDisplayed slots.
  * Fix external monitoring on Linux screen.
  * Fix missing file for Stabilize without Analyze.
  * Fix audio changed by Mask From File video filter.
* Mon Dec 24 2018 davejplater@gmail.com
- Update to 18.12.23
- Upstream changes:
  * Fix #683 Linux start crash with csladspa.
  * Fix simple keyframes for new Mask filters.
  * Remove 90ms delta between refreshes.
  * Add video histogram scope.
  * Make the Export buttons always visible.
  * Add a checkbox for Threshold on Mask: From File.
  * Fix File label in Mask: From File.
* Mon Dec 17 2018 davejplater@gmail.com
- Update to version 18.12.15.
- Package newly installed man page.
- Upstream changes:
  * Fix using luma mask to always use brightness.
  * Add filter Mask: From File.
  * Replace Mask with Simple Shape and Apply.
  * Play from start if try to start play at the end.
  * Automatically add reverse clip to playlist and open it.
  * Let Reverse use project folder.
  * Fix Save not removing autosave file.
  * Fix #677 number of digits export each playlist item.
  * Do not recreate clip if speed was not changed.
  * Update man page and install it. (#676)
  * Add Color Range with override to Properties.
  * Move Reverse out of the Properties menu.
  * Minor improvement for command line usage (#676).
  * Add Levels video filter.
  * Fix New Project > Start does not actually save .mlt file.
  * Fix numeric locale issue in audio visualization filters.
  * Fix backward compat. of audio balance and pan.
  * Add preset and keyframes to audio balance and pan filters.
  * Fix off-by-one error in quality scale conversions.
  * Fix #674 color generator inaccurate.
  * Fix some filters with keyframes and preset.
  * Add more thread locks around autosave file.
  * Fix #671 crash when undo Playlist > Remove All.
  * Include libselinux for Linux.
  * Use mkpath() to create project folder.
* Mon Nov 19 2018 davejplater@gmail.com
- Update to 18.11.18
- Upstream changes:
  Improve reliability of HW encoder auto-config.
  Add MM:SS.SS to Timer Filter.
  Retain metadata when convert or extract sub-clip.
  Add IRE measurement to video waveform scope.
  Alow scroll wheel control of colorwheel.
  Fix HW encoder detection if ffmpeg times out.
  Add setting player/warnGPU (default true).
  Increase video defaults for ABR and CBR.
* Thu Nov 15 2018 davejplater@gmail.com
- Update to 18.11.13 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  Improve VideoToolbox and VAAPI rate control.
  Fix A/V device capture.
  Swap 10 and 20 pixel grid options in menu.
  Fix #663 broken filters on export each playlist item.
  Fix #540 crash on undo of split on Timeline.
  Add checkbox to save state of Export > Advanced.
  Fix uncheck hardware encoder does not reset.
* Sun Nov 11 2018 davejplater@gmail.com
- Update to 18.11.04
- Upstream changes:
  Increase Scale max to 500%%.
  Add Square 1080p video modes.
  Enable video waveform scope.
  Fix reopening Timeline changes zoom level.
  Fix some filters' presets do not save any values.
  Make GPU Effects hidden and discouraged.
  Add VA-API encoding for Linux.
  Make hardware encoder checkbox sticky.
* Wed Oct 17 2018 davejplater@gmail.com
- Update to 18.10.08
- Droid fonts are no longer present.
- Rebased shotcut-QAction.patch and shotcut-noupdatecheck.patch.
- Upstream changes:
  Fix ffmpeg build on macOS and Linux.
  Fix VUI rectangle control's fixed aspect ratio handling.
  Fix timeline rulers inaccurate after video mode fps change.
  Always supply force argument for waveform function calls.
  Fix Text filter preset not saving the text.
  Replace Droid font with Liberation due to incompatible license.
* Fri Aug 17 2018 davejplater@gmail.com
- Update to bugfix release 18.08.14
- Upstream changes:
  Fix loading existing Text filter with animation.
  Fix changing Speed, Duration, or track deletes Comments.
  Fix selecting clip with speed change corrupts XML.
* Tue Aug 14 2018 davejplater@gmail.com
- Update to 18.08.11
- Removed shotcut-desktopfile.patch.
- Rebased shotcut-noupdatecheck.patch.
- Upstream changes:
  Use a queued signal to add transition by drag-n-drop clip.
  Fix crash changing Video Mode with nothing loaded.
  Use multi consumer if export resolution/aspect differs from
  project.
  Fix right-click timeline clip breaks timeline scrolling.
  Fix track name becomes uneditable after click track head.
  Fix #616 util.h included twice.
  Fix making project modified when adding comments or changing sync.
* Thu Jul  5 2018 davejplater@gmail.com
- Removed all trace of droid fonts
* Tue Jul  3 2018 davejplater@gmail.com
- Update to release 18.07.
- For upstream changes see:
  https://www.shotcut.org/blog/new-release-1807/
* Mon Jun 11 2018 davejplater@gmail.com
- Update to release 18.06.02 and rebased patches.
- Fixes build against latest qt5 with shotcut-QAction.patch.
- Upstream changes:
  * Remove the old variant with MLT logo, and add 2x variants.
  * Change app launch splash image.
  * Add Detach Audio to timeline clip context menu.
  * Only use YAML for presets with MLT v6.9.0+
  * Use YAML for filter presets.  *
  * The legacy preset format does not support multiline text. The YAML
  * format does support multiline text. Maintain backwards compatiblity
  * Add double-click action to timeline faders.
  * Double-click toggles between one second and removing the filters.
  * Fix audio filters get incorrect channel count state.
  * Add support for mono and surround to Swap Channels filter.
  * Add mono and surround support the the Copy Channel filter.
  * Set bounds on dragging keyframes.
  * Fix #576 squashed commit of the following:
    Fix nullptr c++11, which we are not using yet.
    Copy file date when converting files.
  * Add support for AMD AMF to Export panel.
  * Add simple and advanced keyframes to Mask filter.
  * Add AMD AMF support to FFmpeg build on Windows.
  * Fix building FFmpeg with NVENC.
  * Add --enable-libjack for FFmpeg 4.0
  * Upgrade to FFmpeg 4.0
  * Add keyframes to Saturation filter.
  * Add a keyboard shortcuts link to the Help menu.
  * Fix #572 restart with command line arguments.
  * Refresh after changing interpolation or deinterlacer.
  * Fix many frames dropped on start of playback from pause.
  * Fix small memory leak in Open Other dialog.
  * Add keyframes to Blur filter.
  * Fix KeyframesButton's tooltip getting stuck showing.
  * Add undo buttons to Size and Position filter UI.
  * Fix #568 libopus breaks audio rate control options.
  * Add Reverse to clip Properties menu.
  * Add many animated presets to Size and Position.
  * Fix filter duration and simple keyframes after split and merge.
  * Fix animate/fade out when trimming in on timeline.
  * Add double-click for simple keyframes.
  * Increase size of avformat producer cache per MLT change.
  * Fix #557 by limiting threads and thus memory usage on 32-bit.
  * Only adjust filter when trimming clip if filter is not trimmed.
  * Use UTF-8 for FFmpeg device strings.
  * Change Mask default rotation to 50%%.
  * Adjust simple keyframes on non-current filters when trimming.
  * Reduce opacity when VUI rectangle control is disabled.
  * Fix #555 track & master filter durations not adjusted.
  * Fix name of master & track filters in Keyframes dock.
  * Additional GPU checking and clarifications.
  * Make MLT XML file dropped onto Playlist into a virtual clip.
  * Fix #554 repeated File > Close crashes.
* Wed May  9 2018 davejplater@gmail.com
- Update to bug fix release 18.05.08
- Upstream changes:
  * Fix QML producer object not updated before loading filter UI.
  * Fix fade out filters incorrect after changing out point.
  * Fix broken fade out control on Timeline.
  * Fix Fade Out Audio raises volume.
  * Fix endOfStream signal off by one frame.
* Sun May  6 2018 davejplater@gmail.com
- Update to release 18.05 and rebased shotcut-noupdatecheck.patch.
- Upstream changes:
  * Added Keyframe support with a new Keyframes panel.
  * Added 5.1 Surround Sound.
  * Added Finnish translation.
  * Restored GIF Animation for Export.
  * Reduced memory footprint (especially for the Rotate and Size and
  Position filters).
  * Changed default Export settings to reduce output size by
  increasing GOP and number of B frames.
  * See https://shotcut.org/blog/new-release-1805/
* Tue Apr 24 2018 davejplater@gmail.com
- Update to bug fix release 18.03.06
- Upstream changes:
  * Fix multiply handled KeyEvent regression in Fix #344 shortcut
  not working with undocked Timeline.Fix multiply handled KeyEvent
  regression in Fix #344 shortcut not working with undocked
  Timeline.
  * Fix added Fade Out Volume shows incorrect on Timeline.
  * Fix track name not editable regression in Fix #344 shortcut not
  working with undocked Timeline.
  * Add Mosaic filter.
* Mon Mar  5 2018 davejplater@gmail.com
- Update to release 18.03
- Upstream changes:
  * Add Estonian translation.
  * Fix existing mask filter loading incorrect values.
  * Fix #500 add transition by trimming may shift a clip.
  * Fix #362 Size filter not using correct decimal symbol.
  * Fix #503 crash setting Video Mode after New.
  * Swap role of Alt+Wheel for timeline scroll.
  * Improve timeline track pad behavior.
  * Fix #497 mouse wheel/trackpad scrolling.
  * Fix #344 shortcut not working with undocked Timeline.
  * Fix #486 JACK transport glitches.
  * Fix #361 JACK client connects itself.
  * Fix #487 split validation off by one frame.
  * Avformat properties improvements.
* Wed Jan  3 2018 davejplater@gmail.com
- Update to 18.01
- Upstream changes:
  * Add a Mask video filter.
  * Add support for size and italics of font.
  * Add Audio Spectrum Visualization filter.
  * Fix duration on image clips with in point > 0.
  * Fix memory leak calling Mlt::Playlist::replace_with_blanks().
  * Fix regression in Fix #474 changing properties of color clip
  changes duration. broke trimmed avformat clips.
  * Fix checkbox on low free space dialog not working.
  * Fix #474 changing properties of color clip changes duration.
  * Fix states for showing convert clip dialog.
  * Fix #431 multi-line text may cause export to hang.
* Sat Dec  9 2017 davejplater@gmail.com
- Update to 17.12 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Adjust timeline faders with filters in panel.
  * Fix #472 adjust timeline faders when add/rm filters in panel.
  * Fix filter on wrong half after a split shows in transition.
  * Show job percentage as text again.
  * Fix #473 JS error in export EDL on orphan transition.
  * Fix #471 GPU processing not switched when needed by project.
  * Make new strings conform to "anymore."
* Thu Dec  7 2017 dimstar@opensuse.org
- Escape the usage of %%{VERSION} when calling out to rpm.
  RPM 4.14 has %%{VERSION} defined as 'the main packages version'.
* Sat Nov  4 2017 davejplater@gmail.com
- Update to 17.11 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Allow toggle GPU processing in any Display Method.
  * Remove the frameDisplayed throttle.
  * Reduce free space theshold to 50 GiB.
  * Add Nepali translation.
  * Add warning if the drive for export is low on space.
  * Display warning if file to export is in project.
  * Pause upon changing timeline zoom.
  * Hide the gif format and codec.
  * Fix adding transition changes selection.
  * Fix #411 Ripple All Tracks not fully splitting clips.
  * Fix Add All to Timeline not including filters.
  * Do not adjust Timeline zoom until slider is released.
* Tue Oct  3 2017 davejplater@gmail.com
- Update to 17.10 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  * Fixed multi-threaded decoding with FFmpeg v3.2.
  * Added 1080p 59.94 and 60 fps video modes.
  * Added support for NVENC to Export panel.
  * Updated SDL to v2.0
  * Updated FFmpeg to v3.2
* Mon Aug 21 2017 olaf@aepfle.de
- Recommend lame unconditionally
* Sat Aug  5 2017 davejplater@gmail.com
- Update to 17.08 and rebase shotcut-noupdatecheck.patch.
- Upstream changes:
  Add Norwegian Bokmål translation.
  Increase maximum of speed field.
  Fix unlinked files dialog not using folder for next open.
  Add another decimal digit of precision to speed.
  Fix fade in/out on clip-only project.
  Fix #442 all image sequences reported missing.
  Increase maximum Timeline zoom level.
  Prevent O key (set out) from pausing playback.
* Fri Jun  9 2017 davejplater@gmail.com
- Update to 17.06
- Require qmelt created in new package webvfx see boo#1043070.
- Upstream changes:
  Add Hungarian translation.
  Fix #428 unable to make image longer than 10 minutes.
  Pin x264 to version before requiring nasm.
  Update Chinese translation file.
* Mon May  8 2017 jengelh@inai.de
- Trim filler words from description
* Thu May  4 2017 davejplater@gmail.com
- Update to 17.05
- Remove auto update with shotcut-noupdatecheck.patch. This also
  enables reproducible builds.
- Rebase shotcut-desktopfile.patch
- Enable libvpx build.
- Upstream changes:
  Fix #412 disable waveform generation when hidden.
  Fix #406 extension included in EDL reel name.
  Fix #405 JavaScript error in Export EDL.
  Use MLT to determine decimal point. (#416)
* Wed May  3 2017 davejplater@gmail.com
- Update to 17.04
- Fix desktop file with shotcut-desktopfile.patch
- Upstream changes:
  Added Japanese translation.
  Added Turkish translation.
  Fix #399 crash after trying to save empty file.
  Do not include <profile> with internal MLT XML.
  Fix missing period before suggested extension.
* Sun Mar  5 2017 davejplater@gmail.com
- Update to 17.03
- Upstream changes:
  Converted the track toggle buttons to icons.
  Now, you can press Del or Backspace to delete a selected item in
  the Recent panel.
  Playback now pauses at the out point in the Source player. (After
  pause, you can press play again to continue beyond the out point.)
  Some stability improvements.
  Performance boost for Size & Position and Rotate filters on
  multi-CPU systems.
* Mon Feb 20 2017 jengelh@inai.de
- Trim description
- Proper shell quoting and replacement of Useless Use Of Cat
  (ls -1).
* Sun Feb  5 2017 mailaender@opensuse.org
- version update to 17.02
- drop fix-building.patch (included upstream)
  * https://github.com/mltframework/shotcut/pull/331
* Fri Oct 28 2016 adrian@suse.com
- version update to 16.10
- fixing build for qt 5.5: fix-building.patch
* Tue Oct 25 2016 davejplater@gmail.com
- Update version 16.08, the highest version to work with qt-5.5
- Required specific version of frei0r-plugins to prevent segfault
- Upstream changes:
    Added count-down (or up) generator: File > Open Other > Count
    Major performance boost for opaque clips on video tracks higher
    than V1 with track Composite enabled and Blend mode: Over.
  Release 16.07
    Added File > Export Frame…
    Added Remove transition to History by trimming a neighboring
    clip to remove it.
    Fixed version checker.
* Sun Oct 23 2016 wbauer@tmo.at
- Required libqt5-qtgraphicaleffects, this is needed for the
  timeline to work. See :
  https://forums.opensuse.org/showthread.php/520592-shotcut-video-editor-timeline-blank/page3
* Wed Jun 15 2016 avvissu@yandex.by
- Update to 16.06:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Add Requires: libvpx
* Wed May  4 2016 avvissu@yandex.by
- Update to 16.05:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Use %%%%make_jobs and %%%%qmake5_install (see: /etc/rpm/macros.qt5)
* Fri Apr  8 2016 avvissu@yandex.by
- Update to 16.04:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Tue Jan 12 2016 avvissu@yandex.ru
- Update to 16.01:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Fri Dec  4 2015 avvissu@yandex.ru
- Update to 15.12:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
* Tue Nov 10 2015 avvissu@yandex.ru
- Update to 15.11:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Use Qt5 >= 5.5.0
- Add BuildRequires: libqt5-qtdeclarative-private-headers-devel
- Use %%%%qmake5 instead of qmake-qt5
- Search for executable files
- Add language packs
* Fri Aug 14 2015 avvissu@yandex.ru
- Update to 15.08:
  * see: http://www.shotcut.org/bin/view/Shotcut/ReleaseNotes
- Add %%BUILD_ORIG macro to build in Packman
- Spec file cleanup
* Sat Nov 30 2013 dap.darkness@gmail.com
- Initial package.
